# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section81Response(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'section_81_reference_number': 'str',
        'date_created': 'datetime',
        'location_description': 'str',
        'section_81_severity': 'Section81SeverityResponse',
        'section_81_severity_string': 'str',
        'section_81_status': 'Section81StatusResponse',
        'section_81_status_string': 'str',
        'section_81_type': 'Section81TypeResponse',
        'section_81_type_string': 'str',
        'work_reference_number': 'str',
        'usrn': 'float',
        'street_name': 'str',
        'town': 'str',
        'area': 'str',
        'road_category': 'float',
        'works_coordinates': 'object',
        'highway_authority': 'str',
        'highway_authority_swa_code': 'str',
        'promoter_organisation': 'str',
        'promoter_swa_code': 'str',
        'workstream_prefix': 'str',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'inspection_date': 'datetime',
        'other_type_details': 'str',
        'made_safe_by_ha': 'bool',
        'inspector_name': 'str',
        'inspector_contact_number': 'str',
        'additional_details': 'str',
        'status_changed_date': 'datetime',
        'promoter_response': 'str',
        'section_81_work_type': 'AllOfSection81ResponseSection81WorkType',
        'section_81_work_type_string': 'str',
        'promoter_status': 'AllOfSection81ResponsePromoterStatus',
        'promoter_status_string': 'str',
        'promoter_status_changed_date': 'datetime',
        'linked_permit': 'AllOfSection81ResponseLinkedPermit',
        'files': 'list[FileSummaryResponse]'
    }

    attribute_map = {
        'section_81_reference_number': 'section_81_reference_number',
        'date_created': 'date_created',
        'location_description': 'location_description',
        'section_81_severity': 'section_81_severity',
        'section_81_severity_string': 'section_81_severity_string',
        'section_81_status': 'section_81_status',
        'section_81_status_string': 'section_81_status_string',
        'section_81_type': 'section_81_type',
        'section_81_type_string': 'section_81_type_string',
        'work_reference_number': 'work_reference_number',
        'usrn': 'usrn',
        'street_name': 'street_name',
        'town': 'town',
        'area': 'area',
        'road_category': 'road_category',
        'works_coordinates': 'works_coordinates',
        'highway_authority': 'highway_authority',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'promoter_organisation': 'promoter_organisation',
        'promoter_swa_code': 'promoter_swa_code',
        'workstream_prefix': 'workstream_prefix',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'inspection_date': 'inspection_date',
        'other_type_details': 'other_type_details',
        'made_safe_by_ha': 'made_safe_by_ha',
        'inspector_name': 'inspector_name',
        'inspector_contact_number': 'inspector_contact_number',
        'additional_details': 'additional_details',
        'status_changed_date': 'status_changed_date',
        'promoter_response': 'promoter_response',
        'section_81_work_type': 'section_81_work_type',
        'section_81_work_type_string': 'section_81_work_type_string',
        'promoter_status': 'promoter_status',
        'promoter_status_string': 'promoter_status_string',
        'promoter_status_changed_date': 'promoter_status_changed_date',
        'linked_permit': 'linked_permit',
        'files': 'files'
    }

    def __init__(self, section_81_reference_number=None, date_created=None, location_description=None, section_81_severity=None, section_81_severity_string=None, section_81_status=None, section_81_status_string=None, section_81_type=None, section_81_type_string=None, work_reference_number=None, usrn=None, street_name=None, town=None, area=None, road_category=None, works_coordinates=None, highway_authority=None, highway_authority_swa_code=None, promoter_organisation=None, promoter_swa_code=None, workstream_prefix=None, location_types=None, location_types_string=None, inspection_date=None, other_type_details=None, made_safe_by_ha=None, inspector_name=None, inspector_contact_number=None, additional_details=None, status_changed_date=None, promoter_response=None, section_81_work_type=None, section_81_work_type_string=None, promoter_status=None, promoter_status_string=None, promoter_status_changed_date=None, linked_permit=None, files=None):  # noqa: E501
        """Section81Response - a model defined in Swagger"""  # noqa: E501
        self._section_81_reference_number = None
        self._date_created = None
        self._location_description = None
        self._section_81_severity = None
        self._section_81_severity_string = None
        self._section_81_status = None
        self._section_81_status_string = None
        self._section_81_type = None
        self._section_81_type_string = None
        self._work_reference_number = None
        self._usrn = None
        self._street_name = None
        self._town = None
        self._area = None
        self._road_category = None
        self._works_coordinates = None
        self._highway_authority = None
        self._highway_authority_swa_code = None
        self._promoter_organisation = None
        self._promoter_swa_code = None
        self._workstream_prefix = None
        self._location_types = None
        self._location_types_string = None
        self._inspection_date = None
        self._other_type_details = None
        self._made_safe_by_ha = None
        self._inspector_name = None
        self._inspector_contact_number = None
        self._additional_details = None
        self._status_changed_date = None
        self._promoter_response = None
        self._section_81_work_type = None
        self._section_81_work_type_string = None
        self._promoter_status = None
        self._promoter_status_string = None
        self._promoter_status_changed_date = None
        self._linked_permit = None
        self._files = None
        self.discriminator = None
        self.section_81_reference_number = section_81_reference_number
        self.date_created = date_created
        self.location_description = location_description
        if section_81_severity is not None:
            self.section_81_severity = section_81_severity
        if section_81_severity_string is not None:
            self.section_81_severity_string = section_81_severity_string
        self.section_81_status = section_81_status
        self.section_81_status_string = section_81_status_string
        self.section_81_type = section_81_type
        self.section_81_type_string = section_81_type_string
        self.work_reference_number = work_reference_number
        self.usrn = usrn
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area is not None:
            self.area = area
        self.road_category = road_category
        self.works_coordinates = works_coordinates
        self.highway_authority = highway_authority
        self.highway_authority_swa_code = highway_authority_swa_code
        self.promoter_organisation = promoter_organisation
        self.promoter_swa_code = promoter_swa_code
        self.workstream_prefix = workstream_prefix
        self.location_types = location_types
        self.location_types_string = location_types_string
        self.inspection_date = inspection_date
        if other_type_details is not None:
            self.other_type_details = other_type_details
        if made_safe_by_ha is not None:
            self.made_safe_by_ha = made_safe_by_ha
        if inspector_name is not None:
            self.inspector_name = inspector_name
        if inspector_contact_number is not None:
            self.inspector_contact_number = inspector_contact_number
        self.additional_details = additional_details
        self.status_changed_date = status_changed_date
        if promoter_response is not None:
            self.promoter_response = promoter_response
        if section_81_work_type is not None:
            self.section_81_work_type = section_81_work_type
        if section_81_work_type_string is not None:
            self.section_81_work_type_string = section_81_work_type_string
        if promoter_status is not None:
            self.promoter_status = promoter_status
        if promoter_status_string is not None:
            self.promoter_status_string = promoter_status_string
        if promoter_status_changed_date is not None:
            self.promoter_status_changed_date = promoter_status_changed_date
        if linked_permit is not None:
            self.linked_permit = linked_permit
        if files is not None:
            self.files = files

    @property
    def section_81_reference_number(self):
        """Gets the section_81_reference_number of this Section81Response.  # noqa: E501


        :return: The section_81_reference_number of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._section_81_reference_number

    @section_81_reference_number.setter
    def section_81_reference_number(self, section_81_reference_number):
        """Sets the section_81_reference_number of this Section81Response.


        :param section_81_reference_number: The section_81_reference_number of this Section81Response.  # noqa: E501
        :type: str
        """
        if section_81_reference_number is None:
            raise ValueError("Invalid value for `section_81_reference_number`, must not be `None`")  # noqa: E501

        self._section_81_reference_number = section_81_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this Section81Response.  # noqa: E501


        :return: The date_created of this Section81Response.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this Section81Response.


        :param date_created: The date_created of this Section81Response.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def location_description(self):
        """Gets the location_description of this Section81Response.  # noqa: E501


        :return: The location_description of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this Section81Response.


        :param location_description: The location_description of this Section81Response.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def section_81_severity(self):
        """Gets the section_81_severity of this Section81Response.  # noqa: E501


        :return: The section_81_severity of this Section81Response.  # noqa: E501
        :rtype: Section81SeverityResponse
        """
        return self._section_81_severity

    @section_81_severity.setter
    def section_81_severity(self, section_81_severity):
        """Sets the section_81_severity of this Section81Response.


        :param section_81_severity: The section_81_severity of this Section81Response.  # noqa: E501
        :type: Section81SeverityResponse
        """

        self._section_81_severity = section_81_severity

    @property
    def section_81_severity_string(self):
        """Gets the section_81_severity_string of this Section81Response.  # noqa: E501


        :return: The section_81_severity_string of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._section_81_severity_string

    @section_81_severity_string.setter
    def section_81_severity_string(self, section_81_severity_string):
        """Sets the section_81_severity_string of this Section81Response.


        :param section_81_severity_string: The section_81_severity_string of this Section81Response.  # noqa: E501
        :type: str
        """

        self._section_81_severity_string = section_81_severity_string

    @property
    def section_81_status(self):
        """Gets the section_81_status of this Section81Response.  # noqa: E501


        :return: The section_81_status of this Section81Response.  # noqa: E501
        :rtype: Section81StatusResponse
        """
        return self._section_81_status

    @section_81_status.setter
    def section_81_status(self, section_81_status):
        """Sets the section_81_status of this Section81Response.


        :param section_81_status: The section_81_status of this Section81Response.  # noqa: E501
        :type: Section81StatusResponse
        """
        if section_81_status is None:
            raise ValueError("Invalid value for `section_81_status`, must not be `None`")  # noqa: E501

        self._section_81_status = section_81_status

    @property
    def section_81_status_string(self):
        """Gets the section_81_status_string of this Section81Response.  # noqa: E501


        :return: The section_81_status_string of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._section_81_status_string

    @section_81_status_string.setter
    def section_81_status_string(self, section_81_status_string):
        """Sets the section_81_status_string of this Section81Response.


        :param section_81_status_string: The section_81_status_string of this Section81Response.  # noqa: E501
        :type: str
        """
        if section_81_status_string is None:
            raise ValueError("Invalid value for `section_81_status_string`, must not be `None`")  # noqa: E501

        self._section_81_status_string = section_81_status_string

    @property
    def section_81_type(self):
        """Gets the section_81_type of this Section81Response.  # noqa: E501


        :return: The section_81_type of this Section81Response.  # noqa: E501
        :rtype: Section81TypeResponse
        """
        return self._section_81_type

    @section_81_type.setter
    def section_81_type(self, section_81_type):
        """Sets the section_81_type of this Section81Response.


        :param section_81_type: The section_81_type of this Section81Response.  # noqa: E501
        :type: Section81TypeResponse
        """
        if section_81_type is None:
            raise ValueError("Invalid value for `section_81_type`, must not be `None`")  # noqa: E501

        self._section_81_type = section_81_type

    @property
    def section_81_type_string(self):
        """Gets the section_81_type_string of this Section81Response.  # noqa: E501


        :return: The section_81_type_string of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._section_81_type_string

    @section_81_type_string.setter
    def section_81_type_string(self, section_81_type_string):
        """Sets the section_81_type_string of this Section81Response.


        :param section_81_type_string: The section_81_type_string of this Section81Response.  # noqa: E501
        :type: str
        """
        if section_81_type_string is None:
            raise ValueError("Invalid value for `section_81_type_string`, must not be `None`")  # noqa: E501

        self._section_81_type_string = section_81_type_string

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this Section81Response.  # noqa: E501


        :return: The work_reference_number of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this Section81Response.


        :param work_reference_number: The work_reference_number of this Section81Response.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def usrn(self):
        """Gets the usrn of this Section81Response.  # noqa: E501


        :return: The usrn of this Section81Response.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this Section81Response.


        :param usrn: The usrn of this Section81Response.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def street_name(self):
        """Gets the street_name of this Section81Response.  # noqa: E501


        :return: The street_name of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this Section81Response.


        :param street_name: The street_name of this Section81Response.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this Section81Response.  # noqa: E501


        :return: The town of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this Section81Response.


        :param town: The town of this Section81Response.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area(self):
        """Gets the area of this Section81Response.  # noqa: E501


        :return: The area of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this Section81Response.


        :param area: The area of this Section81Response.  # noqa: E501
        :type: str
        """

        self._area = area

    @property
    def road_category(self):
        """Gets the road_category of this Section81Response.  # noqa: E501


        :return: The road_category of this Section81Response.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this Section81Response.


        :param road_category: The road_category of this Section81Response.  # noqa: E501
        :type: float
        """
        if road_category is None:
            raise ValueError("Invalid value for `road_category`, must not be `None`")  # noqa: E501

        self._road_category = road_category

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this Section81Response.  # noqa: E501


        :return: The works_coordinates of this Section81Response.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this Section81Response.


        :param works_coordinates: The works_coordinates of this Section81Response.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def highway_authority(self):
        """Gets the highway_authority of this Section81Response.  # noqa: E501


        :return: The highway_authority of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority

    @highway_authority.setter
    def highway_authority(self, highway_authority):
        """Sets the highway_authority of this Section81Response.


        :param highway_authority: The highway_authority of this Section81Response.  # noqa: E501
        :type: str
        """
        if highway_authority is None:
            raise ValueError("Invalid value for `highway_authority`, must not be `None`")  # noqa: E501

        self._highway_authority = highway_authority

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this Section81Response.  # noqa: E501


        :return: The highway_authority_swa_code of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this Section81Response.


        :param highway_authority_swa_code: The highway_authority_swa_code of this Section81Response.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this Section81Response.  # noqa: E501


        :return: The promoter_organisation of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this Section81Response.


        :param promoter_organisation: The promoter_organisation of this Section81Response.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this Section81Response.  # noqa: E501


        :return: The promoter_swa_code of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this Section81Response.


        :param promoter_swa_code: The promoter_swa_code of this Section81Response.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def workstream_prefix(self):
        """Gets the workstream_prefix of this Section81Response.  # noqa: E501


        :return: The workstream_prefix of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._workstream_prefix

    @workstream_prefix.setter
    def workstream_prefix(self, workstream_prefix):
        """Sets the workstream_prefix of this Section81Response.


        :param workstream_prefix: The workstream_prefix of this Section81Response.  # noqa: E501
        :type: str
        """
        if workstream_prefix is None:
            raise ValueError("Invalid value for `workstream_prefix`, must not be `None`")  # noqa: E501

        self._workstream_prefix = workstream_prefix

    @property
    def location_types(self):
        """Gets the location_types of this Section81Response.  # noqa: E501


        :return: The location_types of this Section81Response.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this Section81Response.


        :param location_types: The location_types of this Section81Response.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this Section81Response.  # noqa: E501


        :return: The location_types_string of this Section81Response.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this Section81Response.


        :param location_types_string: The location_types_string of this Section81Response.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def inspection_date(self):
        """Gets the inspection_date of this Section81Response.  # noqa: E501


        :return: The inspection_date of this Section81Response.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_date

    @inspection_date.setter
    def inspection_date(self, inspection_date):
        """Sets the inspection_date of this Section81Response.


        :param inspection_date: The inspection_date of this Section81Response.  # noqa: E501
        :type: datetime
        """
        if inspection_date is None:
            raise ValueError("Invalid value for `inspection_date`, must not be `None`")  # noqa: E501

        self._inspection_date = inspection_date

    @property
    def other_type_details(self):
        """Gets the other_type_details of this Section81Response.  # noqa: E501


        :return: The other_type_details of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._other_type_details

    @other_type_details.setter
    def other_type_details(self, other_type_details):
        """Sets the other_type_details of this Section81Response.


        :param other_type_details: The other_type_details of this Section81Response.  # noqa: E501
        :type: str
        """

        self._other_type_details = other_type_details

    @property
    def made_safe_by_ha(self):
        """Gets the made_safe_by_ha of this Section81Response.  # noqa: E501


        :return: The made_safe_by_ha of this Section81Response.  # noqa: E501
        :rtype: bool
        """
        return self._made_safe_by_ha

    @made_safe_by_ha.setter
    def made_safe_by_ha(self, made_safe_by_ha):
        """Sets the made_safe_by_ha of this Section81Response.


        :param made_safe_by_ha: The made_safe_by_ha of this Section81Response.  # noqa: E501
        :type: bool
        """

        self._made_safe_by_ha = made_safe_by_ha

    @property
    def inspector_name(self):
        """Gets the inspector_name of this Section81Response.  # noqa: E501


        :return: The inspector_name of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._inspector_name

    @inspector_name.setter
    def inspector_name(self, inspector_name):
        """Sets the inspector_name of this Section81Response.


        :param inspector_name: The inspector_name of this Section81Response.  # noqa: E501
        :type: str
        """

        self._inspector_name = inspector_name

    @property
    def inspector_contact_number(self):
        """Gets the inspector_contact_number of this Section81Response.  # noqa: E501


        :return: The inspector_contact_number of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._inspector_contact_number

    @inspector_contact_number.setter
    def inspector_contact_number(self, inspector_contact_number):
        """Sets the inspector_contact_number of this Section81Response.


        :param inspector_contact_number: The inspector_contact_number of this Section81Response.  # noqa: E501
        :type: str
        """

        self._inspector_contact_number = inspector_contact_number

    @property
    def additional_details(self):
        """Gets the additional_details of this Section81Response.  # noqa: E501


        :return: The additional_details of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """Sets the additional_details of this Section81Response.


        :param additional_details: The additional_details of this Section81Response.  # noqa: E501
        :type: str
        """
        if additional_details is None:
            raise ValueError("Invalid value for `additional_details`, must not be `None`")  # noqa: E501

        self._additional_details = additional_details

    @property
    def status_changed_date(self):
        """Gets the status_changed_date of this Section81Response.  # noqa: E501


        :return: The status_changed_date of this Section81Response.  # noqa: E501
        :rtype: datetime
        """
        return self._status_changed_date

    @status_changed_date.setter
    def status_changed_date(self, status_changed_date):
        """Sets the status_changed_date of this Section81Response.


        :param status_changed_date: The status_changed_date of this Section81Response.  # noqa: E501
        :type: datetime
        """
        if status_changed_date is None:
            raise ValueError("Invalid value for `status_changed_date`, must not be `None`")  # noqa: E501

        self._status_changed_date = status_changed_date

    @property
    def promoter_response(self):
        """Gets the promoter_response of this Section81Response.  # noqa: E501


        :return: The promoter_response of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response

    @promoter_response.setter
    def promoter_response(self, promoter_response):
        """Sets the promoter_response of this Section81Response.


        :param promoter_response: The promoter_response of this Section81Response.  # noqa: E501
        :type: str
        """

        self._promoter_response = promoter_response

    @property
    def section_81_work_type(self):
        """Gets the section_81_work_type of this Section81Response.  # noqa: E501


        :return: The section_81_work_type of this Section81Response.  # noqa: E501
        :rtype: AllOfSection81ResponseSection81WorkType
        """
        return self._section_81_work_type

    @section_81_work_type.setter
    def section_81_work_type(self, section_81_work_type):
        """Sets the section_81_work_type of this Section81Response.


        :param section_81_work_type: The section_81_work_type of this Section81Response.  # noqa: E501
        :type: AllOfSection81ResponseSection81WorkType
        """

        self._section_81_work_type = section_81_work_type

    @property
    def section_81_work_type_string(self):
        """Gets the section_81_work_type_string of this Section81Response.  # noqa: E501


        :return: The section_81_work_type_string of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._section_81_work_type_string

    @section_81_work_type_string.setter
    def section_81_work_type_string(self, section_81_work_type_string):
        """Sets the section_81_work_type_string of this Section81Response.


        :param section_81_work_type_string: The section_81_work_type_string of this Section81Response.  # noqa: E501
        :type: str
        """

        self._section_81_work_type_string = section_81_work_type_string

    @property
    def promoter_status(self):
        """Gets the promoter_status of this Section81Response.  # noqa: E501


        :return: The promoter_status of this Section81Response.  # noqa: E501
        :rtype: AllOfSection81ResponsePromoterStatus
        """
        return self._promoter_status

    @promoter_status.setter
    def promoter_status(self, promoter_status):
        """Sets the promoter_status of this Section81Response.


        :param promoter_status: The promoter_status of this Section81Response.  # noqa: E501
        :type: AllOfSection81ResponsePromoterStatus
        """

        self._promoter_status = promoter_status

    @property
    def promoter_status_string(self):
        """Gets the promoter_status_string of this Section81Response.  # noqa: E501


        :return: The promoter_status_string of this Section81Response.  # noqa: E501
        :rtype: str
        """
        return self._promoter_status_string

    @promoter_status_string.setter
    def promoter_status_string(self, promoter_status_string):
        """Sets the promoter_status_string of this Section81Response.


        :param promoter_status_string: The promoter_status_string of this Section81Response.  # noqa: E501
        :type: str
        """

        self._promoter_status_string = promoter_status_string

    @property
    def promoter_status_changed_date(self):
        """Gets the promoter_status_changed_date of this Section81Response.  # noqa: E501


        :return: The promoter_status_changed_date of this Section81Response.  # noqa: E501
        :rtype: datetime
        """
        return self._promoter_status_changed_date

    @promoter_status_changed_date.setter
    def promoter_status_changed_date(self, promoter_status_changed_date):
        """Sets the promoter_status_changed_date of this Section81Response.


        :param promoter_status_changed_date: The promoter_status_changed_date of this Section81Response.  # noqa: E501
        :type: datetime
        """

        self._promoter_status_changed_date = promoter_status_changed_date

    @property
    def linked_permit(self):
        """Gets the linked_permit of this Section81Response.  # noqa: E501


        :return: The linked_permit of this Section81Response.  # noqa: E501
        :rtype: AllOfSection81ResponseLinkedPermit
        """
        return self._linked_permit

    @linked_permit.setter
    def linked_permit(self, linked_permit):
        """Sets the linked_permit of this Section81Response.


        :param linked_permit: The linked_permit of this Section81Response.  # noqa: E501
        :type: AllOfSection81ResponseLinkedPermit
        """

        self._linked_permit = linked_permit

    @property
    def files(self):
        """Gets the files of this Section81Response.  # noqa: E501


        :return: The files of this Section81Response.  # noqa: E501
        :rtype: list[FileSummaryResponse]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this Section81Response.


        :param files: The files of this Section81Response.  # noqa: E501
        :type: list[FileSummaryResponse]
        """

        self._files = files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section81Response, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section81Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Street Manager Street Lookup API

    See API specification Resource Guide > Street Lookup API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from .additional_special_designation_code_response import AdditionalSpecialDesignationCodeResponse
from .additional_special_designations_periodicity_code_response import AdditionalSpecialDesignationsPeriodicityCodeResponse
from .additional_special_designations_response import AdditionalSpecialDesignationsResponse
from .all_of_additional_special_designations_response_asd_coordinate_geometry import AllOfAdditionalSpecialDesignationsResponseAsdCoordinateGeometry
from .all_of_additional_special_designations_response_special_desig_periodicity_code import AllOfAdditionalSpecialDesignationsResponseSpecialDesigPeriodicityCode
from .all_of_street_response_street_centre_point import AllOfStreetResponseStreetCentrePoint
from .all_of_street_response_street_line import AllOfStreetResponseStreetLine
from .coordinates import Coordinates
from .geo_json_centre_point import GeoJSONCentrePoint
from .geo_json_centre_point_type import GeoJSONCentrePointType
from .geo_json_feature_type_response import GeoJSONFeatureTypeResponse
from .geo_json_geometry import GeoJSONGeometry
from .geo_json_multi_line_string import GeoJSONMultiLineString
from .geo_json_multi_line_string_type import GeoJSONMultiLineStringType
from .interest_authority import InterestAuthority
from .primary_notice_authority import PrimaryNoticeAuthority
from .reinstatement_type_code_response import ReinstatementTypeCodeResponse
from .reinstatement_type_details import ReinstatementTypeDetails
from .street_response import StreetResponse
from .street_summary_response import StreetSummaryResponse
from .streets_request import StreetsRequest
from .usrn_street_request import UsrnStreetRequest



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitAlterationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'permit_alteration_reference_number': 'str',
        'date_created': 'datetime',
        'deadline_date': 'datetime',
        'alteration_status': 'AlterationStatusResponse',
        'alteration_status_string': 'str',
        'alteration_type': 'AlterationTypeResponse',
        'alteration_type_string': 'str',
        'permit_status': 'AllOfPermitAlterationResponsePermitStatus',
        'permit_status_string': 'str',
        'assessment_discount': 'float',
        'assessment_comments': 'str',
        'permit_alteration_reason': 'str',
        'original': 'PermitResponse',
        'proposed': 'PermitResponse',
        'duration_challenge_review_status': 'AllOfPermitAlterationResponseDurationChallengeReviewStatus',
        'duration_challenge_review_status_string': 'str',
        'duration_challenge_reason_for_non_acceptance': 'str',
        'duration_challenge_review_update_date': 'datetime',
        'duration_challenge_non_acceptance_response_status': 'AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus',
        'duration_challenge_non_acceptance_response_status_string': 'str',
        'duration_challenge_non_acceptance_response_details': 'str',
        'duration_challenge_non_acceptance_response_update_date': 'datetime',
        'duration_challenge_non_acceptance_response_new_reasonable_period_end_date': 'datetime',
        'duration_challenge_non_acceptance_response_old_reasonable_period_end_date': 'datetime',
        'duration_challenge_follow_up_review_complete': 'bool'
    }

    attribute_map = {
        'permit_alteration_reference_number': 'permit_alteration_reference_number',
        'date_created': 'date_created',
        'deadline_date': 'deadline_date',
        'alteration_status': 'alteration_status',
        'alteration_status_string': 'alteration_status_string',
        'alteration_type': 'alteration_type',
        'alteration_type_string': 'alteration_type_string',
        'permit_status': 'permit_status',
        'permit_status_string': 'permit_status_string',
        'assessment_discount': 'assessment_discount',
        'assessment_comments': 'assessment_comments',
        'permit_alteration_reason': 'permit_alteration_reason',
        'original': 'original',
        'proposed': 'proposed',
        'duration_challenge_review_status': 'duration_challenge_review_status',
        'duration_challenge_review_status_string': 'duration_challenge_review_status_string',
        'duration_challenge_reason_for_non_acceptance': 'duration_challenge_reason_for_non_acceptance',
        'duration_challenge_review_update_date': 'duration_challenge_review_update_date',
        'duration_challenge_non_acceptance_response_status': 'duration_challenge_non_acceptance_response_status',
        'duration_challenge_non_acceptance_response_status_string': 'duration_challenge_non_acceptance_response_status_string',
        'duration_challenge_non_acceptance_response_details': 'duration_challenge_non_acceptance_response_details',
        'duration_challenge_non_acceptance_response_update_date': 'duration_challenge_non_acceptance_response_update_date',
        'duration_challenge_non_acceptance_response_new_reasonable_period_end_date': 'duration_challenge_non_acceptance_response_new_reasonable_period_end_date',
        'duration_challenge_non_acceptance_response_old_reasonable_period_end_date': 'duration_challenge_non_acceptance_response_old_reasonable_period_end_date',
        'duration_challenge_follow_up_review_complete': 'duration_challenge_follow_up_review_complete'
    }

    def __init__(self, permit_alteration_reference_number=None, date_created=None, deadline_date=None, alteration_status=None, alteration_status_string=None, alteration_type=None, alteration_type_string=None, permit_status=None, permit_status_string=None, assessment_discount=None, assessment_comments=None, permit_alteration_reason=None, original=None, proposed=None, duration_challenge_review_status=None, duration_challenge_review_status_string=None, duration_challenge_reason_for_non_acceptance=None, duration_challenge_review_update_date=None, duration_challenge_non_acceptance_response_status=None, duration_challenge_non_acceptance_response_status_string=None, duration_challenge_non_acceptance_response_details=None, duration_challenge_non_acceptance_response_update_date=None, duration_challenge_non_acceptance_response_new_reasonable_period_end_date=None, duration_challenge_non_acceptance_response_old_reasonable_period_end_date=None, duration_challenge_follow_up_review_complete=None):  # noqa: E501
        """PermitAlterationResponse - a model defined in Swagger"""  # noqa: E501
        self._permit_alteration_reference_number = None
        self._date_created = None
        self._deadline_date = None
        self._alteration_status = None
        self._alteration_status_string = None
        self._alteration_type = None
        self._alteration_type_string = None
        self._permit_status = None
        self._permit_status_string = None
        self._assessment_discount = None
        self._assessment_comments = None
        self._permit_alteration_reason = None
        self._original = None
        self._proposed = None
        self._duration_challenge_review_status = None
        self._duration_challenge_review_status_string = None
        self._duration_challenge_reason_for_non_acceptance = None
        self._duration_challenge_review_update_date = None
        self._duration_challenge_non_acceptance_response_status = None
        self._duration_challenge_non_acceptance_response_status_string = None
        self._duration_challenge_non_acceptance_response_details = None
        self._duration_challenge_non_acceptance_response_update_date = None
        self._duration_challenge_non_acceptance_response_new_reasonable_period_end_date = None
        self._duration_challenge_non_acceptance_response_old_reasonable_period_end_date = None
        self._duration_challenge_follow_up_review_complete = None
        self.discriminator = None
        self.permit_alteration_reference_number = permit_alteration_reference_number
        self.date_created = date_created
        self.deadline_date = deadline_date
        self.alteration_status = alteration_status
        self.alteration_status_string = alteration_status_string
        self.alteration_type = alteration_type
        self.alteration_type_string = alteration_type_string
        if permit_status is not None:
            self.permit_status = permit_status
        if permit_status_string is not None:
            self.permit_status_string = permit_status_string
        if assessment_discount is not None:
            self.assessment_discount = assessment_discount
        if assessment_comments is not None:
            self.assessment_comments = assessment_comments
        self.permit_alteration_reason = permit_alteration_reason
        self.original = original
        self.proposed = proposed
        if duration_challenge_review_status is not None:
            self.duration_challenge_review_status = duration_challenge_review_status
        if duration_challenge_review_status_string is not None:
            self.duration_challenge_review_status_string = duration_challenge_review_status_string
        if duration_challenge_reason_for_non_acceptance is not None:
            self.duration_challenge_reason_for_non_acceptance = duration_challenge_reason_for_non_acceptance
        if duration_challenge_review_update_date is not None:
            self.duration_challenge_review_update_date = duration_challenge_review_update_date
        if duration_challenge_non_acceptance_response_status is not None:
            self.duration_challenge_non_acceptance_response_status = duration_challenge_non_acceptance_response_status
        if duration_challenge_non_acceptance_response_status_string is not None:
            self.duration_challenge_non_acceptance_response_status_string = duration_challenge_non_acceptance_response_status_string
        if duration_challenge_non_acceptance_response_details is not None:
            self.duration_challenge_non_acceptance_response_details = duration_challenge_non_acceptance_response_details
        if duration_challenge_non_acceptance_response_update_date is not None:
            self.duration_challenge_non_acceptance_response_update_date = duration_challenge_non_acceptance_response_update_date
        if duration_challenge_non_acceptance_response_new_reasonable_period_end_date is not None:
            self.duration_challenge_non_acceptance_response_new_reasonable_period_end_date = duration_challenge_non_acceptance_response_new_reasonable_period_end_date
        if duration_challenge_non_acceptance_response_old_reasonable_period_end_date is not None:
            self.duration_challenge_non_acceptance_response_old_reasonable_period_end_date = duration_challenge_non_acceptance_response_old_reasonable_period_end_date
        if duration_challenge_follow_up_review_complete is not None:
            self.duration_challenge_follow_up_review_complete = duration_challenge_follow_up_review_complete

    @property
    def permit_alteration_reference_number(self):
        """Gets the permit_alteration_reference_number of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_alteration_reference_number of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_alteration_reference_number

    @permit_alteration_reference_number.setter
    def permit_alteration_reference_number(self, permit_alteration_reference_number):
        """Sets the permit_alteration_reference_number of this PermitAlterationResponse.


        :param permit_alteration_reference_number: The permit_alteration_reference_number of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if permit_alteration_reference_number is None:
            raise ValueError("Invalid value for `permit_alteration_reference_number`, must not be `None`")  # noqa: E501

        self._permit_alteration_reference_number = permit_alteration_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this PermitAlterationResponse.  # noqa: E501


        :return: The date_created of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this PermitAlterationResponse.


        :param date_created: The date_created of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def deadline_date(self):
        """Gets the deadline_date of this PermitAlterationResponse.  # noqa: E501


        :return: The deadline_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._deadline_date

    @deadline_date.setter
    def deadline_date(self, deadline_date):
        """Sets the deadline_date of this PermitAlterationResponse.


        :param deadline_date: The deadline_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """
        if deadline_date is None:
            raise ValueError("Invalid value for `deadline_date`, must not be `None`")  # noqa: E501

        self._deadline_date = deadline_date

    @property
    def alteration_status(self):
        """Gets the alteration_status of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AlterationStatusResponse
        """
        return self._alteration_status

    @alteration_status.setter
    def alteration_status(self, alteration_status):
        """Sets the alteration_status of this PermitAlterationResponse.


        :param alteration_status: The alteration_status of this PermitAlterationResponse.  # noqa: E501
        :type: AlterationStatusResponse
        """
        if alteration_status is None:
            raise ValueError("Invalid value for `alteration_status`, must not be `None`")  # noqa: E501

        self._alteration_status = alteration_status

    @property
    def alteration_status_string(self):
        """Gets the alteration_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._alteration_status_string

    @alteration_status_string.setter
    def alteration_status_string(self, alteration_status_string):
        """Sets the alteration_status_string of this PermitAlterationResponse.


        :param alteration_status_string: The alteration_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if alteration_status_string is None:
            raise ValueError("Invalid value for `alteration_status_string`, must not be `None`")  # noqa: E501

        self._alteration_status_string = alteration_status_string

    @property
    def alteration_type(self):
        """Gets the alteration_type of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_type of this PermitAlterationResponse.  # noqa: E501
        :rtype: AlterationTypeResponse
        """
        return self._alteration_type

    @alteration_type.setter
    def alteration_type(self, alteration_type):
        """Sets the alteration_type of this PermitAlterationResponse.


        :param alteration_type: The alteration_type of this PermitAlterationResponse.  # noqa: E501
        :type: AlterationTypeResponse
        """
        if alteration_type is None:
            raise ValueError("Invalid value for `alteration_type`, must not be `None`")  # noqa: E501

        self._alteration_type = alteration_type

    @property
    def alteration_type_string(self):
        """Gets the alteration_type_string of this PermitAlterationResponse.  # noqa: E501


        :return: The alteration_type_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._alteration_type_string

    @alteration_type_string.setter
    def alteration_type_string(self, alteration_type_string):
        """Sets the alteration_type_string of this PermitAlterationResponse.


        :param alteration_type_string: The alteration_type_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if alteration_type_string is None:
            raise ValueError("Invalid value for `alteration_type_string`, must not be `None`")  # noqa: E501

        self._alteration_type_string = alteration_type_string

    @property
    def permit_status(self):
        """Gets the permit_status of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AllOfPermitAlterationResponsePermitStatus
        """
        return self._permit_status

    @permit_status.setter
    def permit_status(self, permit_status):
        """Sets the permit_status of this PermitAlterationResponse.


        :param permit_status: The permit_status of this PermitAlterationResponse.  # noqa: E501
        :type: AllOfPermitAlterationResponsePermitStatus
        """

        self._permit_status = permit_status

    @property
    def permit_status_string(self):
        """Gets the permit_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_status_string

    @permit_status_string.setter
    def permit_status_string(self, permit_status_string):
        """Sets the permit_status_string of this PermitAlterationResponse.


        :param permit_status_string: The permit_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._permit_status_string = permit_status_string

    @property
    def assessment_discount(self):
        """Gets the assessment_discount of this PermitAlterationResponse.  # noqa: E501


        :return: The assessment_discount of this PermitAlterationResponse.  # noqa: E501
        :rtype: float
        """
        return self._assessment_discount

    @assessment_discount.setter
    def assessment_discount(self, assessment_discount):
        """Sets the assessment_discount of this PermitAlterationResponse.


        :param assessment_discount: The assessment_discount of this PermitAlterationResponse.  # noqa: E501
        :type: float
        """

        self._assessment_discount = assessment_discount

    @property
    def assessment_comments(self):
        """Gets the assessment_comments of this PermitAlterationResponse.  # noqa: E501


        :return: The assessment_comments of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._assessment_comments

    @assessment_comments.setter
    def assessment_comments(self, assessment_comments):
        """Sets the assessment_comments of this PermitAlterationResponse.


        :param assessment_comments: The assessment_comments of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._assessment_comments = assessment_comments

    @property
    def permit_alteration_reason(self):
        """Gets the permit_alteration_reason of this PermitAlterationResponse.  # noqa: E501


        :return: The permit_alteration_reason of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_alteration_reason

    @permit_alteration_reason.setter
    def permit_alteration_reason(self, permit_alteration_reason):
        """Sets the permit_alteration_reason of this PermitAlterationResponse.


        :param permit_alteration_reason: The permit_alteration_reason of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """
        if permit_alteration_reason is None:
            raise ValueError("Invalid value for `permit_alteration_reason`, must not be `None`")  # noqa: E501

        self._permit_alteration_reason = permit_alteration_reason

    @property
    def original(self):
        """Gets the original of this PermitAlterationResponse.  # noqa: E501


        :return: The original of this PermitAlterationResponse.  # noqa: E501
        :rtype: PermitResponse
        """
        return self._original

    @original.setter
    def original(self, original):
        """Sets the original of this PermitAlterationResponse.


        :param original: The original of this PermitAlterationResponse.  # noqa: E501
        :type: PermitResponse
        """
        if original is None:
            raise ValueError("Invalid value for `original`, must not be `None`")  # noqa: E501

        self._original = original

    @property
    def proposed(self):
        """Gets the proposed of this PermitAlterationResponse.  # noqa: E501


        :return: The proposed of this PermitAlterationResponse.  # noqa: E501
        :rtype: PermitResponse
        """
        return self._proposed

    @proposed.setter
    def proposed(self, proposed):
        """Sets the proposed of this PermitAlterationResponse.


        :param proposed: The proposed of this PermitAlterationResponse.  # noqa: E501
        :type: PermitResponse
        """
        if proposed is None:
            raise ValueError("Invalid value for `proposed`, must not be `None`")  # noqa: E501

        self._proposed = proposed

    @property
    def duration_challenge_review_status(self):
        """Gets the duration_challenge_review_status of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_review_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AllOfPermitAlterationResponseDurationChallengeReviewStatus
        """
        return self._duration_challenge_review_status

    @duration_challenge_review_status.setter
    def duration_challenge_review_status(self, duration_challenge_review_status):
        """Sets the duration_challenge_review_status of this PermitAlterationResponse.


        :param duration_challenge_review_status: The duration_challenge_review_status of this PermitAlterationResponse.  # noqa: E501
        :type: AllOfPermitAlterationResponseDurationChallengeReviewStatus
        """

        self._duration_challenge_review_status = duration_challenge_review_status

    @property
    def duration_challenge_review_status_string(self):
        """Gets the duration_challenge_review_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_review_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_review_status_string

    @duration_challenge_review_status_string.setter
    def duration_challenge_review_status_string(self, duration_challenge_review_status_string):
        """Sets the duration_challenge_review_status_string of this PermitAlterationResponse.


        :param duration_challenge_review_status_string: The duration_challenge_review_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_review_status_string = duration_challenge_review_status_string

    @property
    def duration_challenge_reason_for_non_acceptance(self):
        """Gets the duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_reason_for_non_acceptance

    @duration_challenge_reason_for_non_acceptance.setter
    def duration_challenge_reason_for_non_acceptance(self, duration_challenge_reason_for_non_acceptance):
        """Sets the duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.


        :param duration_challenge_reason_for_non_acceptance: The duration_challenge_reason_for_non_acceptance of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_reason_for_non_acceptance = duration_challenge_reason_for_non_acceptance

    @property
    def duration_challenge_review_update_date(self):
        """Gets the duration_challenge_review_update_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_review_update_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_review_update_date

    @duration_challenge_review_update_date.setter
    def duration_challenge_review_update_date(self, duration_challenge_review_update_date):
        """Sets the duration_challenge_review_update_date of this PermitAlterationResponse.


        :param duration_challenge_review_update_date: The duration_challenge_review_update_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_review_update_date = duration_challenge_review_update_date

    @property
    def duration_challenge_non_acceptance_response_status(self):
        """Gets the duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.  # noqa: E501
        :rtype: AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus
        """
        return self._duration_challenge_non_acceptance_response_status

    @duration_challenge_non_acceptance_response_status.setter
    def duration_challenge_non_acceptance_response_status(self, duration_challenge_non_acceptance_response_status):
        """Sets the duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_status: The duration_challenge_non_acceptance_response_status of this PermitAlterationResponse.  # noqa: E501
        :type: AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus
        """

        self._duration_challenge_non_acceptance_response_status = duration_challenge_non_acceptance_response_status

    @property
    def duration_challenge_non_acceptance_response_status_string(self):
        """Gets the duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_non_acceptance_response_status_string

    @duration_challenge_non_acceptance_response_status_string.setter
    def duration_challenge_non_acceptance_response_status_string(self, duration_challenge_non_acceptance_response_status_string):
        """Sets the duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_status_string: The duration_challenge_non_acceptance_response_status_string of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_non_acceptance_response_status_string = duration_challenge_non_acceptance_response_status_string

    @property
    def duration_challenge_non_acceptance_response_details(self):
        """Gets the duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.  # noqa: E501
        :rtype: str
        """
        return self._duration_challenge_non_acceptance_response_details

    @duration_challenge_non_acceptance_response_details.setter
    def duration_challenge_non_acceptance_response_details(self, duration_challenge_non_acceptance_response_details):
        """Sets the duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_details: The duration_challenge_non_acceptance_response_details of this PermitAlterationResponse.  # noqa: E501
        :type: str
        """

        self._duration_challenge_non_acceptance_response_details = duration_challenge_non_acceptance_response_details

    @property
    def duration_challenge_non_acceptance_response_update_date(self):
        """Gets the duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_non_acceptance_response_update_date

    @duration_challenge_non_acceptance_response_update_date.setter
    def duration_challenge_non_acceptance_response_update_date(self, duration_challenge_non_acceptance_response_update_date):
        """Sets the duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_update_date: The duration_challenge_non_acceptance_response_update_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_non_acceptance_response_update_date = duration_challenge_non_acceptance_response_update_date

    @property
    def duration_challenge_non_acceptance_response_new_reasonable_period_end_date(self):
        """Gets the duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_non_acceptance_response_new_reasonable_period_end_date

    @duration_challenge_non_acceptance_response_new_reasonable_period_end_date.setter
    def duration_challenge_non_acceptance_response_new_reasonable_period_end_date(self, duration_challenge_non_acceptance_response_new_reasonable_period_end_date):
        """Sets the duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_new_reasonable_period_end_date: The duration_challenge_non_acceptance_response_new_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_non_acceptance_response_new_reasonable_period_end_date = duration_challenge_non_acceptance_response_new_reasonable_period_end_date

    @property
    def duration_challenge_non_acceptance_response_old_reasonable_period_end_date(self):
        """Gets the duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._duration_challenge_non_acceptance_response_old_reasonable_period_end_date

    @duration_challenge_non_acceptance_response_old_reasonable_period_end_date.setter
    def duration_challenge_non_acceptance_response_old_reasonable_period_end_date(self, duration_challenge_non_acceptance_response_old_reasonable_period_end_date):
        """Sets the duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.


        :param duration_challenge_non_acceptance_response_old_reasonable_period_end_date: The duration_challenge_non_acceptance_response_old_reasonable_period_end_date of this PermitAlterationResponse.  # noqa: E501
        :type: datetime
        """

        self._duration_challenge_non_acceptance_response_old_reasonable_period_end_date = duration_challenge_non_acceptance_response_old_reasonable_period_end_date

    @property
    def duration_challenge_follow_up_review_complete(self):
        """Gets the duration_challenge_follow_up_review_complete of this PermitAlterationResponse.  # noqa: E501


        :return: The duration_challenge_follow_up_review_complete of this PermitAlterationResponse.  # noqa: E501
        :rtype: bool
        """
        return self._duration_challenge_follow_up_review_complete

    @duration_challenge_follow_up_review_complete.setter
    def duration_challenge_follow_up_review_complete(self, duration_challenge_follow_up_review_complete):
        """Sets the duration_challenge_follow_up_review_complete of this PermitAlterationResponse.


        :param duration_challenge_follow_up_review_complete: The duration_challenge_follow_up_review_complete of this PermitAlterationResponse.  # noqa: E501
        :type: bool
        """

        self._duration_challenge_follow_up_review_complete = duration_challenge_follow_up_review_complete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitAlterationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitAlterationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from .api import DefaultApi
# import ApiClient
from .api_client import ApiClient
from .configuration import Configuration
# import models into sdk package
from .models.asd_code import ASDCode
from .models.asd_code_response import ASDCodeResponse
from .models.asd_periodicity_code import ASDPeriodicityCode
from .models.asd_periodicity_code_response import ASDPeriodicityCodeResponse
from .models.activity_activity_type import ActivityActivityType
from .models.activity_activity_type_response import ActivityActivityTypeResponse
from .models.activity_cancel_request import ActivityCancelRequest
from .models.activity_create_request import ActivityCreateRequest
from .models.activity_create_response import ActivityCreateResponse
from .models.activity_response import ActivityResponse
from .models.activity_type import ActivityType
from .models.activity_type_response import ActivityTypeResponse
from .models.activity_update_request import ActivityUpdateRequest
from .models.add_file_to_work_request import AddFileToWorkRequest
from .models.all_of_forward_plan_create_request_hs2_highway_exemption import AllOfForwardPlanCreateRequestHs2HighwayExemption
from .models.all_of_forward_plan_create_request_hs2_work_type import AllOfForwardPlanCreateRequestHs2WorkType
from .models.all_of_forward_plan_create_request_traffic_management_type import AllOfForwardPlanCreateRequestTrafficManagementType
from .models.all_of_forward_plan_response_hs2_highway_exemption import AllOfForwardPlanResponseHs2HighwayExemption
from .models.all_of_forward_plan_response_hs2_works_type import AllOfForwardPlanResponseHs2WorksType
from .models.all_of_forward_plan_response_traffic_management_type import AllOfForwardPlanResponseTrafficManagementType
from .models.all_of_forward_plan_update_request_traffic_management_type import AllOfForwardPlanUpdateRequestTrafficManagementType
from .models.all_of_historic_inspection_create_request_defect_fixed_on_site import AllOfHistoricInspectionCreateRequestDefectFixedOnSite
from .models.all_of_historic_inspection_create_request_inspection_category import AllOfHistoricInspectionCreateRequestInspectionCategory
from .models.all_of_historic_inspection_create_request_reinspection_category import AllOfHistoricInspectionCreateRequestReinspectionCategory
from .models.all_of_historic_inspection_create_request_reinspection_type import AllOfHistoricInspectionCreateRequestReinspectionType
from .models.all_of_inspection_create_request_defect_fixed_on_site import AllOfInspectionCreateRequestDefectFixedOnSite
from .models.all_of_inspection_create_request_inspection_category import AllOfInspectionCreateRequestInspectionCategory
from .models.all_of_inspection_create_request_reinspection_category import AllOfInspectionCreateRequestReinspectionCategory
from .models.all_of_inspection_create_request_reinspection_type import AllOfInspectionCreateRequestReinspectionType
from .models.all_of_inspection_response_defect_fixed_on_site import AllOfInspectionResponseDefectFixedOnSite
from .models.all_of_inspection_response_ha_response_status import AllOfInspectionResponseHaResponseStatus
from .models.all_of_inspection_response_inspection_category import AllOfInspectionResponseInspectionCategory
from .models.all_of_inspection_response_inspection_reason_for_withdrawal import AllOfInspectionResponseInspectionReasonForWithdrawal
from .models.all_of_inspection_response_promoter_response_status import AllOfInspectionResponsePromoterResponseStatus
from .models.all_of_inspection_summary_response_inspection_category import AllOfInspectionSummaryResponseInspectionCategory
from .models.all_of_inspection_summary_response_inspection_outcome import AllOfInspectionSummaryResponseInspectionOutcome
from .models.all_of_material_classification_response_file import AllOfMaterialClassificationResponseFile
from .models.all_of_non_compliance_response_jsm_status import AllOfNonComplianceResponseJsmStatus
from .models.all_of_non_compliance_response_promoter_response_status import AllOfNonComplianceResponsePromoterResponseStatus
from .models.all_of_permit_asd_response_special_desig_periodicity_code import AllOfPermitASDResponseSpecialDesigPeriodicityCode
from .models.all_of_permit_asd_special_desig_periodicity_code import AllOfPermitASDSpecialDesigPeriodicityCode
from .models.all_of_permit_alteration_create_request_collaboration_type import AllOfPermitAlterationCreateRequestCollaborationType
from .models.all_of_permit_alteration_response_duration_challenge_non_acceptance_response_status import AllOfPermitAlterationResponseDurationChallengeNonAcceptanceResponseStatus
from .models.all_of_permit_alteration_response_duration_challenge_review_status import AllOfPermitAlterationResponseDurationChallengeReviewStatus
from .models.all_of_permit_alteration_response_permit_status import AllOfPermitAlterationResponsePermitStatus
from .models.all_of_permit_create_request_collaboration_type import AllOfPermitCreateRequestCollaborationType
from .models.all_of_permit_create_request_hs2_highway_exemption import AllOfPermitCreateRequestHs2HighwayExemption
from .models.all_of_permit_lane_rental_assessment_update_request_charge_band import AllOfPermitLaneRentalAssessmentUpdateRequestChargeBand
from .models.all_of_permit_response_assessment_status import AllOfPermitResponseAssessmentStatus
from .models.all_of_permit_response_collaboration_type import AllOfPermitResponseCollaborationType
from .models.all_of_permit_response_current_traffic_management_type import AllOfPermitResponseCurrentTrafficManagementType
from .models.all_of_permit_response_duration_challenge_non_acceptance_response_status import AllOfPermitResponseDurationChallengeNonAcceptanceResponseStatus
from .models.all_of_permit_response_duration_challenge_review_status import AllOfPermitResponseDurationChallengeReviewStatus
from .models.all_of_permit_response_hs2_highway_exemption import AllOfPermitResponseHs2HighwayExemption
from .models.all_of_permit_response_lane_rental_assessment_charge_band import AllOfPermitResponseLaneRentalAssessmentChargeBand
from .models.all_of_permit_response_lane_rental_assessment_outcome import AllOfPermitResponseLaneRentalAssessmentOutcome
from .models.all_of_permit_response_linked_section81 import AllOfPermitResponseLinkedSection81
from .models.all_of_permit_response_permit_cancellation_reason import AllOfPermitResponsePermitCancellationReason
from .models.all_of_permit_status_update_request_permit_cancellation_reason import AllOfPermitStatusUpdateRequestPermitCancellationReason
from .models.all_of_scheduled_inspection_create_request_scheduled_inspection_category import AllOfScheduledInspectionCreateRequestScheduledInspectionCategory
from .models.all_of_section74_response_promoter_status import AllOfSection74ResponsePromoterStatus
from .models.all_of_section81_create_request_section81_severity import AllOfSection81CreateRequestSection81Severity
from .models.all_of_section81_response_linked_permit import AllOfSection81ResponseLinkedPermit
from .models.all_of_section81_response_promoter_status import AllOfSection81ResponsePromoterStatus
from .models.all_of_section81_response_section81_work_type import AllOfSection81ResponseSection81WorkType
from .models.all_of_section81_status_update_request_work_type import AllOfSection81StatusUpdateRequestWorkType
from .models.all_of_work_create_request_collaboration_type import AllOfWorkCreateRequestCollaborationType
from .models.all_of_work_create_request_hs2_highway_exemption import AllOfWorkCreateRequestHs2HighwayExemption
from .models.all_of_work_response_active_permit import AllOfWorkResponseActivePermit
from .models.all_of_work_response_forward_plan import AllOfWorkResponseForwardPlan
from .models.all_of_work_response_private_street_notice import AllOfWorkResponsePrivateStreetNotice
from .models.all_of_work_response_promoter_organisation_industry_type import AllOfWorkResponsePromoterOrganisationIndustryType
from .models.all_of_work_response_section81 import AllOfWorkResponseSection81
from .models.alteration_status import AlterationStatus
from .models.alteration_status_response import AlterationStatusResponse
from .models.alteration_type_response import AlterationTypeResponse
from .models.ancillary_info_response import AncillaryInfoResponse
from .models.ancillary_info_status_response import AncillaryInfoStatusResponse
from .models.ancillary_info_summary_response import AncillaryInfoSummaryResponse
from .models.ancillary_info_type import AncillaryInfoType
from .models.ancillary_info_type_response import AncillaryInfoTypeResponse
from .models.application_type import ApplicationType
from .models.application_type_response import ApplicationTypeResponse
from .models.assessment_status import AssessmentStatus
from .models.assessment_status_response import AssessmentStatusResponse
from .models.audit_event import AuditEvent
from .models.authentication_request import AuthenticationRequest
from .models.authentication_response import AuthenticationResponse
from .models.close_footpath import CloseFootpath
from .models.close_footpath_response import CloseFootpathResponse
from .models.close_footway import CloseFootway
from .models.close_footway_response import CloseFootwayResponse
from .models.collaboration_type import CollaborationType
from .models.collaboration_type_response import CollaborationTypeResponse
from .models.comment_create_request import CommentCreateRequest
from .models.comment_create_response import CommentCreateResponse
from .models.comment_read_request import CommentReadRequest
from .models.comment_response import CommentResponse
from .models.comment_topic import CommentTopic
from .models.comment_topic_response import CommentTopicResponse
from .models.create_ancillary_info_request import CreateAncillaryInfoRequest
from .models.create_ancillary_info_response import CreateAncillaryInfoResponse
from .models.current_traffic_management_type_request import CurrentTrafficManagementTypeRequest
from .models.defect_fixed_onsite import DefectFixedOnsite
from .models.defect_fixed_onsite_response import DefectFixedOnsiteResponse
from .models.duration_calculation_response import DurationCalculationResponse
from .models.duration_challenge_non_acceptance_response_status import DurationChallengeNonAcceptanceResponseStatus
from .models.duration_challenge_non_acceptance_response_status_response import DurationChallengeNonAcceptanceResponseStatusResponse
from .models.duration_challenge_review_status import DurationChallengeReviewStatus
from .models.duration_challenge_review_status_response import DurationChallengeReviewStatusResponse
from .models.excavation_carried_out_update_request import ExcavationCarriedOutUpdateRequest
from .models.fpn_create_request import FPNCreateRequest
from .models.fpn_create_response import FPNCreateResponse
from .models.fpn_response import FPNResponse
from .models.fpn_status import FPNStatus
from .models.fpn_status_response import FPNStatusResponse
from .models.fpn_status_update_request import FPNStatusUpdateRequest
from .models.fpn_summary_response import FPNSummaryResponse
from .models.failure_reason import FailureReason
from .models.failure_reason_details import FailureReasonDetails
from .models.failure_reason_details_response import FailureReasonDetailsResponse
from .models.failure_reason_response import FailureReasonResponse
from .models.fee_matrix_request import FeeMatrixRequest
from .models.fee_matrix_response import FeeMatrixResponse
from .models.file_response import FileResponse
from .models.file_summary_response import FileSummaryResponse
from .models.files_body import FilesBody
from .models.final_reinstatement_update_request import FinalReinstatementUpdateRequest
from .models.forward_plan_cancel_request import ForwardPlanCancelRequest
from .models.forward_plan_create_request import ForwardPlanCreateRequest
from .models.forward_plan_create_response import ForwardPlanCreateResponse
from .models.forward_plan_response import ForwardPlanResponse
from .models.forward_plan_status_response import ForwardPlanStatusResponse
from .models.forward_plan_summary_response import ForwardPlanSummaryResponse
from .models.forward_plan_update_request import ForwardPlanUpdateRequest
from .models.forward_plan_work_type import ForwardPlanWorkType
from .models.forward_plan_work_type_response import ForwardPlanWorkTypeResponse
from .models.geographical_area_create_response import GeographicalAreaCreateResponse
from .models.geographicalareas_body import GeographicalareasBody
from .models.geographicalareas_geographical_area_reference_number_body import GeographicalareasGeographicalAreaReferenceNumberBody
from .models.hs2_acknowledgement_request import HS2AcknowledgementRequest
from .models.hs2_highway_exemption import HS2HighwayExemption
from .models.hs2_highway_exemption_response import HS2HighwayExemptionResponse
from .models.hazardous_material_type import HazardousMaterialType
from .models.hazardous_material_type_response import HazardousMaterialTypeResponse
from .models.historic_fpn_create_request import HistoricFPNCreateRequest
from .models.historic_fpn_create_response import HistoricFPNCreateResponse
from .models.historic_failure_reason_details import HistoricFailureReasonDetails
from .models.historic_inspection_create_request import HistoricInspectionCreateRequest
from .models.historic_inspection_create_response import HistoricInspectionCreateResponse
from .models.impose_change_request import ImposeChangeRequest
from .models.impose_change_response import ImposeChangeResponse
from .models.industry_sector_response import IndustrySectorResponse
from .models.initial_authentication_response import InitialAuthenticationResponse
from .models.inspection_category import InspectionCategory
from .models.inspection_category_response import InspectionCategoryResponse
from .models.inspection_create_request import InspectionCreateRequest
from .models.inspection_create_response import InspectionCreateResponse
from .models.inspection_outcome import InspectionOutcome
from .models.inspection_outcome_response import InspectionOutcomeResponse
from .models.inspection_outcome_status_request import InspectionOutcomeStatusRequest
from .models.inspection_outcome_status_type import InspectionOutcomeStatusType
from .models.inspection_outcome_status_type_response import InspectionOutcomeStatusTypeResponse
from .models.inspection_reason_for_withdrawal import InspectionReasonForWithdrawal
from .models.inspection_reason_for_withdrawal_response import InspectionReasonForWithdrawalResponse
from .models.inspection_response import InspectionResponse
from .models.inspection_response_type_response import InspectionResponseTypeResponse
from .models.inspection_status_response import InspectionStatusResponse
from .models.inspection_summary_response import InspectionSummaryResponse
from .models.inspection_type import InspectionType
from .models.inspection_type_response import InspectionTypeResponse
from .models.inspection_withdraw_request import InspectionWithdrawRequest
from .models.interested_party import InterestedParty
from .models.jsm_status_response import JsmStatusResponse
from .models.lane_rental_assessment_charge_band import LaneRentalAssessmentChargeBand
from .models.lane_rental_assessment_charge_band_response import LaneRentalAssessmentChargeBandResponse
from .models.lane_rental_assessment_outcome import LaneRentalAssessmentOutcome
from .models.lane_rental_assessment_outcome_response import LaneRentalAssessmentOutcomeResponse
from .models.layer_affected import LayerAffected
from .models.layer_affected_response import LayerAffectedResponse
from .models.link_section81_to_permit_request import LinkSection81ToPermitRequest
from .models.link_section81_to_permit_response import LinkSection81ToPermitResponse
from .models.linked_permit import LinkedPermit
from .models.linked_section81 import LinkedSection81
from .models.location_type import LocationType
from .models.location_type_response import LocationTypeResponse
from .models.mark_permit_as_under_assessment_request import MarkPermitAsUnderAssessmentRequest
from .models.material_classification_classification import MaterialClassificationClassification
from .models.material_classification_classification_response import MaterialClassificationClassificationResponse
from .models.material_classification_create_request import MaterialClassificationCreateRequest
from .models.material_classification_create_response import MaterialClassificationCreateResponse
from .models.material_classification_response import MaterialClassificationResponse
from .models.non_compliance_response import NonComplianceResponse
from .models.non_compliance_response_status import NonComplianceResponseStatus
from .models.non_compliance_response_status_request import NonComplianceResponseStatusRequest
from .models.non_compliance_response_status_response import NonComplianceResponseStatusResponse
from .models.non_compliance_status_response import NonComplianceStatusResponse
from .models.non_compliance_summary_response import NonComplianceSummaryResponse
from .models.non_notifiable_site_create_request import NonNotifiableSiteCreateRequest
from .models.non_notifiable_site_create_response import NonNotifiableSiteCreateResponse
from .models.offence_code import OffenceCode
from .models.offence_code_response import OffenceCodeResponse
from .models.overrun_warning_reason import OverrunWarningReason
from .models.overrun_warning_reason_response import OverrunWarningReasonResponse
from .models.pagination_details import PaginationDetails
from .models.payment_method import PaymentMethod
from .models.payment_method_response import PaymentMethodResponse
from .models.pbi_sample_inspection_summary_response import PbiSampleInspectionSummaryResponse
from .models.permit_asd import PermitASD
from .models.permit_asd_response import PermitASDResponse
from .models.permit_alteration_create_request import PermitAlterationCreateRequest
from .models.permit_alteration_create_response import PermitAlterationCreateResponse
from .models.permit_alteration_duration_challenge_non_acceptance_response_request import PermitAlterationDurationChallengeNonAcceptanceResponseRequest
from .models.permit_alteration_duration_challenge_review_request import PermitAlterationDurationChallengeReviewRequest
from .models.permit_alteration_response import PermitAlterationResponse
from .models.permit_alteration_status_update_request import PermitAlterationStatusUpdateRequest
from .models.permit_alteration_summary_response import PermitAlterationSummaryResponse
from .models.permit_assessment_update_request import PermitAssessmentUpdateRequest
from .models.permit_cancellation_reason import PermitCancellationReason
from .models.permit_cancellation_reason_response import PermitCancellationReasonResponse
from .models.permit_condition import PermitCondition
from .models.permit_condition_response import PermitConditionResponse
from .models.permit_condition_type import PermitConditionType
from .models.permit_condition_type_response import PermitConditionTypeResponse
from .models.permit_create_request import PermitCreateRequest
from .models.permit_create_response import PermitCreateResponse
from .models.permit_discount_update_request import PermitDiscountUpdateRequest
from .models.permit_duration_challenge_non_acceptance_response_request import PermitDurationChallengeNonAcceptanceResponseRequest
from .models.permit_duration_challenge_review_request import PermitDurationChallengeReviewRequest
from .models.permit_lane_rental_assessment_update_request import PermitLaneRentalAssessmentUpdateRequest
from .models.permit_non_compliance_link_request import PermitNonComplianceLinkRequest
from .models.permit_response import PermitResponse
from .models.permit_status import PermitStatus
from .models.permit_status_response import PermitStatusResponse
from .models.permit_status_update_request import PermitStatusUpdateRequest
from .models.permit_summary_response import PermitSummaryResponse
from .models.private_street_notice_cancel_request import PrivateStreetNoticeCancelRequest
from .models.private_street_notice_create_request import PrivateStreetNoticeCreateRequest
from .models.private_street_notice_create_response import PrivateStreetNoticeCreateResponse
from .models.private_street_notice_response import PrivateStreetNoticeResponse
from .models.private_street_status_response import PrivateStreetStatusResponse
from .models.private_street_summary_response import PrivateStreetSummaryResponse
from .models.reason_for_refusal import ReasonForRefusal
from .models.reason_for_refusal_response import ReasonForRefusalResponse
from .models.reassign_section81_request import ReassignSection81Request
from .models.reinstatement_create_request import ReinstatementCreateRequest
from .models.reinstatement_create_response import ReinstatementCreateResponse
from .models.reinstatement_response import ReinstatementResponse
from .models.reinstatement_status import ReinstatementStatus
from .models.reinstatement_status_response import ReinstatementStatusResponse
from .models.reinstatement_type import ReinstatementType
from .models.reinstatement_type_response import ReinstatementTypeResponse
from .models.remove_ancillary_info_request import RemoveAncillaryInfoRequest
from .models.remove_ancillary_info_response import RemoveAncillaryInfoResponse
from .models.scheduled_inspection_create_request import ScheduledInspectionCreateRequest
from .models.section58_create_request import Section58CreateRequest
from .models.section58_create_response import Section58CreateResponse
from .models.section58_duration import Section58Duration
from .models.section58_duration_response import Section58DurationResponse
from .models.section58_extent import Section58Extent
from .models.section58_extent_response import Section58ExtentResponse
from .models.section58_response import Section58Response
from .models.section58_status import Section58Status
from .models.section58_status_response import Section58StatusResponse
from .models.section58_update_status_request import Section58UpdateStatusRequest
from .models.section74_create_request import Section74CreateRequest
from .models.section74_create_response import Section74CreateResponse
from .models.section74_ha_status import Section74HAStatus
from .models.section74_ha_status_response import Section74HAStatusResponse
from .models.section74_promoter_status import Section74PromoterStatus
from .models.section74_promoter_status_response import Section74PromoterStatusResponse
from .models.section74_response import Section74Response
from .models.section74_summary_response import Section74SummaryResponse
from .models.section74_update_ha_status_request import Section74UpdateHAStatusRequest
from .models.section74_update_promoter_status_request import Section74UpdatePromoterStatusRequest
from .models.section81_create_request import Section81CreateRequest
from .models.section81_create_response import Section81CreateResponse
from .models.section81_response import Section81Response
from .models.section81_severity import Section81Severity
from .models.section81_severity_response import Section81SeverityResponse
from .models.section81_status import Section81Status
from .models.section81_status_response import Section81StatusResponse
from .models.section81_status_update_request import Section81StatusUpdateRequest
from .models.section81_summary_response import Section81SummaryResponse
from .models.section81_type import Section81Type
from .models.section81_type_response import Section81TypeResponse
from .models.section81_work_type import Section81WorkType
from .models.section81_work_type_response import Section81WorkTypeResponse
from .models.site_create_request import SiteCreateRequest
from .models.site_create_response import SiteCreateResponse
from .models.site_details import SiteDetails
from .models.site_response import SiteResponse
from .models.site_summary_response import SiteSummaryResponse
from .models.subsume_site_request import SubsumeSiteRequest
from .models.traffic_management_type import TrafficManagementType
from .models.traffic_management_type_response import TrafficManagementTypeResponse
from .models.unlink_section81_from_permit_request import UnlinkSection81FromPermitRequest
from .models.work_category_response import WorkCategoryResponse
from .models.work_category_response_enum import WorkCategoryResponseEnum
from .models.work_create_request import WorkCreateRequest
from .models.work_create_response import WorkCreateResponse
from .models.work_history_response import WorkHistoryResponse
from .models.work_history_summary_response import WorkHistorySummaryResponse
from .models.work_response import WorkResponse
from .models.work_start_revert_request import WorkStartRevertRequest
from .models.work_start_update_request import WorkStartUpdateRequest
from .models.work_status_response import WorkStatusResponse
from .models.work_stop_revert_request import WorkStopRevertRequest
from .models.work_stop_update_request import WorkStopUpdateRequest
from .models.work_type import WorkType
from .models.work_type_response import WorkTypeResponse



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NonNotifiableSiteCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'promoter_swa_code': 'str',
        'highway_authority_swa_code': 'str',
        'works_coordinates': 'object',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'float',
        'road_category': 'float',
        'work_reference_number': 'str',
        'workstream_prefix': 'str',
        'reinstatement_type': 'ReinstatementType',
        'reinstatement_status': 'ReinstatementStatus',
        'reinstatement_date': 'datetime',
        'reinstatement_coordinates': 'object',
        'secondary_reinstatement_coordinates': 'object',
        'location_description': 'str',
        'location_types': 'list[LocationType]',
        'reinstatement_evidence': 'bool',
        'file_ids': 'list[float]',
        'number_of_holes': 'float'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'promoter_swa_code': 'promoter_swa_code',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'works_coordinates': 'works_coordinates',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'road_category': 'road_category',
        'work_reference_number': 'work_reference_number',
        'workstream_prefix': 'workstream_prefix',
        'reinstatement_type': 'reinstatement_type',
        'reinstatement_status': 'reinstatement_status',
        'reinstatement_date': 'reinstatement_date',
        'reinstatement_coordinates': 'reinstatement_coordinates',
        'secondary_reinstatement_coordinates': 'secondary_reinstatement_coordinates',
        'location_description': 'location_description',
        'location_types': 'location_types',
        'reinstatement_evidence': 'reinstatement_evidence',
        'file_ids': 'file_ids',
        'number_of_holes': 'number_of_holes'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, promoter_swa_code=None, highway_authority_swa_code=None, works_coordinates=None, street_name=None, town=None, area_name=None, usrn=None, road_category=None, work_reference_number=None, workstream_prefix=None, reinstatement_type=None, reinstatement_status=None, reinstatement_date=None, reinstatement_coordinates=None, secondary_reinstatement_coordinates=None, location_description=None, location_types=None, reinstatement_evidence=None, file_ids=None, number_of_holes=None):  # noqa: E501
        """NonNotifiableSiteCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._promoter_swa_code = None
        self._highway_authority_swa_code = None
        self._works_coordinates = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._road_category = None
        self._work_reference_number = None
        self._workstream_prefix = None
        self._reinstatement_type = None
        self._reinstatement_status = None
        self._reinstatement_date = None
        self._reinstatement_coordinates = None
        self._secondary_reinstatement_coordinates = None
        self._location_description = None
        self._location_types = None
        self._reinstatement_evidence = None
        self._file_ids = None
        self._number_of_holes = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.promoter_swa_code = promoter_swa_code
        self.highway_authority_swa_code = highway_authority_swa_code
        self.works_coordinates = works_coordinates
        if street_name is not None:
            self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        if road_category is not None:
            self.road_category = road_category
        if work_reference_number is not None:
            self.work_reference_number = work_reference_number
        if workstream_prefix is not None:
            self.workstream_prefix = workstream_prefix
        self.reinstatement_type = reinstatement_type
        self.reinstatement_status = reinstatement_status
        self.reinstatement_date = reinstatement_date
        self.reinstatement_coordinates = reinstatement_coordinates
        if secondary_reinstatement_coordinates is not None:
            self.secondary_reinstatement_coordinates = secondary_reinstatement_coordinates
        self.location_description = location_description
        self.location_types = location_types
        self.reinstatement_evidence = reinstatement_evidence
        if file_ids is not None:
            self.file_ids = file_ids
        self.number_of_holes = number_of_holes

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this NonNotifiableSiteCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this NonNotifiableSiteCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The promoter_swa_code of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this NonNotifiableSiteCreateRequest.

        Max length 4 characters  # noqa: E501

        :param promoter_swa_code: The promoter_swa_code of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The highway_authority_swa_code of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this NonNotifiableSiteCreateRequest.

        Max length 4 characters  # noqa: E501

        :param highway_authority_swa_code: The highway_authority_swa_code of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The works_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this NonNotifiableSiteCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param works_coordinates: The works_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def street_name(self):
        """Gets the street_name of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The street_name of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this NonNotifiableSiteCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param street_name: The street_name of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The town of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this NonNotifiableSiteCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param town: The town of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The area_name of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this NonNotifiableSiteCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param area_name: The area_name of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :return: The usrn of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this NonNotifiableSiteCreateRequest.

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :param usrn: The usrn of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def road_category(self):
        """Gets the road_category of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Is whole number between 0 and 10 inclusive If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The road_category of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this NonNotifiableSiteCreateRequest.

        Is whole number between 0 and 10 inclusive If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param road_category: The road_category of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: float
        """

        self._road_category = road_category

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 24 characters Must be unique in the system Must contain only alphanumeric characters, dashes and underscores If not supplied it will be auto-generated  # noqa: E501

        :return: The work_reference_number of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this NonNotifiableSiteCreateRequest.

        Max length 24 characters Must be unique in the system Must contain only alphanumeric characters, dashes and underscores If not supplied it will be auto-generated  # noqa: E501

        :param work_reference_number: The work_reference_number of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._work_reference_number = work_reference_number

    @property
    def workstream_prefix(self):
        """Gets the workstream_prefix of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Must consist of 3 positive whole numbers. Default workstream if not provided  # noqa: E501

        :return: The workstream_prefix of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._workstream_prefix

    @workstream_prefix.setter
    def workstream_prefix(self, workstream_prefix):
        """Sets the workstream_prefix of this NonNotifiableSiteCreateRequest.

        Must consist of 3 positive whole numbers. Default workstream if not provided  # noqa: E501

        :param workstream_prefix: The workstream_prefix of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """

        self._workstream_prefix = workstream_prefix

    @property
    def reinstatement_type(self):
        """Gets the reinstatement_type of this NonNotifiableSiteCreateRequest.  # noqa: E501


        :return: The reinstatement_type of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: ReinstatementType
        """
        return self._reinstatement_type

    @reinstatement_type.setter
    def reinstatement_type(self, reinstatement_type):
        """Sets the reinstatement_type of this NonNotifiableSiteCreateRequest.


        :param reinstatement_type: The reinstatement_type of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: ReinstatementType
        """
        if reinstatement_type is None:
            raise ValueError("Invalid value for `reinstatement_type`, must not be `None`")  # noqa: E501

        self._reinstatement_type = reinstatement_type

    @property
    def reinstatement_status(self):
        """Gets the reinstatement_status of this NonNotifiableSiteCreateRequest.  # noqa: E501


        :return: The reinstatement_status of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: ReinstatementStatus
        """
        return self._reinstatement_status

    @reinstatement_status.setter
    def reinstatement_status(self, reinstatement_status):
        """Sets the reinstatement_status of this NonNotifiableSiteCreateRequest.


        :param reinstatement_status: The reinstatement_status of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: ReinstatementStatus
        """
        if reinstatement_status is None:
            raise ValueError("Invalid value for `reinstatement_status`, must not be `None`")  # noqa: E501

        self._reinstatement_status = reinstatement_status

    @property
    def reinstatement_date(self):
        """Gets the reinstatement_date of this NonNotifiableSiteCreateRequest.  # noqa: E501

        reinstatement_date must be in the past Must be after actual start date Must be before actual end date (if entered)  # noqa: E501

        :return: The reinstatement_date of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinstatement_date

    @reinstatement_date.setter
    def reinstatement_date(self, reinstatement_date):
        """Sets the reinstatement_date of this NonNotifiableSiteCreateRequest.

        reinstatement_date must be in the past Must be after actual start date Must be before actual end date (if entered)  # noqa: E501

        :param reinstatement_date: The reinstatement_date of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: datetime
        """
        if reinstatement_date is None:
            raise ValueError("Invalid value for `reinstatement_date`, must not be `None`")  # noqa: E501

        self._reinstatement_date = reinstatement_date

    @property
    def reinstatement_coordinates(self):
        """Gets the reinstatement_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The reinstatement_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._reinstatement_coordinates

    @reinstatement_coordinates.setter
    def reinstatement_coordinates(self, reinstatement_coordinates):
        """Sets the reinstatement_coordinates of this NonNotifiableSiteCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param reinstatement_coordinates: The reinstatement_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: object
        """
        if reinstatement_coordinates is None:
            raise ValueError("Invalid value for `reinstatement_coordinates`, must not be `None`")  # noqa: E501

        self._reinstatement_coordinates = reinstatement_coordinates

    @property
    def secondary_reinstatement_coordinates(self):
        """Gets the secondary_reinstatement_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon, if provided  # noqa: E501

        :return: The secondary_reinstatement_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._secondary_reinstatement_coordinates

    @secondary_reinstatement_coordinates.setter
    def secondary_reinstatement_coordinates(self, secondary_reinstatement_coordinates):
        """Sets the secondary_reinstatement_coordinates of this NonNotifiableSiteCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon, if provided  # noqa: E501

        :param secondary_reinstatement_coordinates: The secondary_reinstatement_coordinates of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: object
        """

        self._secondary_reinstatement_coordinates = secondary_reinstatement_coordinates

    @property
    def location_description(self):
        """Gets the location_description of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The location_description of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this NonNotifiableSiteCreateRequest.

        Max length 500 characters  # noqa: E501

        :param location_description: The location_description of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def location_types(self):
        """Gets the location_types of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Array values must be unique Must not contain null or undefined values  # noqa: E501

        :return: The location_types of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: list[LocationType]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this NonNotifiableSiteCreateRequest.

        Array values must be unique Must not contain null or undefined values  # noqa: E501

        :param location_types: The location_types of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: list[LocationType]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def reinstatement_evidence(self):
        """Gets the reinstatement_evidence of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Whether reinstatement evidence has been supplied  # noqa: E501

        :return: The reinstatement_evidence of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._reinstatement_evidence

    @reinstatement_evidence.setter
    def reinstatement_evidence(self, reinstatement_evidence):
        """Sets the reinstatement_evidence of this NonNotifiableSiteCreateRequest.

        Whether reinstatement evidence has been supplied  # noqa: E501

        :param reinstatement_evidence: The reinstatement_evidence of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: bool
        """
        if reinstatement_evidence is None:
            raise ValueError("Invalid value for `reinstatement_evidence`, must not be `None`")  # noqa: E501

        self._reinstatement_evidence = reinstatement_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Required if reinstatement_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this NonNotifiableSiteCreateRequest.

        Required if reinstatement_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    @property
    def number_of_holes(self):
        """Gets the number_of_holes of this NonNotifiableSiteCreateRequest.  # noqa: E501

        Must be a number between 0 and 100  # noqa: E501

        :return: The number_of_holes of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._number_of_holes

    @number_of_holes.setter
    def number_of_holes(self, number_of_holes):
        """Sets the number_of_holes of this NonNotifiableSiteCreateRequest.

        Must be a number between 0 and 100  # noqa: E501

        :param number_of_holes: The number_of_holes of this NonNotifiableSiteCreateRequest.  # noqa: E501
        :type: float
        """
        if number_of_holes is None:
            raise ValueError("Invalid value for `number_of_holes`, must not be `None`")  # noqa: E501

        self._number_of_holes = number_of_holes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NonNotifiableSiteCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NonNotifiableSiteCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script processes Python files within each 'swagger_client' directory
(e.g., src/streetmanager/work/swagger_client, src/streetmanager/geojson/swagger_client, etc.).

For each Python file, it:
1. Calculates the necessary relative import prefix ('.', '..', etc.) based on the
   file's depth relative to its 'swagger_client' root directory.
2. Provides specific, robust fixes for 'swagger_client/__init__.py' and
   'swagger_client/api/__init__.py' to ensure correct package structure.
3. For all other files, converts absolute imports like 'from swagger_client.module import Name'
   to 'from <prefix>.module import Name'.
"""

import re
from pathlib import Path

def print_debug_info(file_path: Path, content: str, stage: str):
    print(f"--- DEBUG: {stage} for {file_path.name} ---")
    if file_path.name == "__init__.py" or "default_api.py" in file_path.name:
        lines = content.splitlines()
        for i, line in enumerate(lines):
            if "DefaultApi" in line or "api_client" in line or "configuration" in line or "models" in line or "swagger_client" in line:
                print(f"  L{i+1}: {line}")
    print(f"--- END DEBUG: {stage} for {file_path.name} ---")

def convert_imports_in_file(file_path: Path, swagger_client_root: Path, project_root: Path):
    """
    Converts absolute 'swagger_client.' imports to relative imports in a single file.
    Prioritizes specific fixes for __init__.py files.
    """
    try:
        content = file_path.read_text(encoding='utf-8')
    except Exception as e:
        print(f"Error reading file {file_path}: {e}")
        return
    
    original_content = content
    print_debug_info(file_path, original_content, "Before processing")

    current_filename = file_path.name
    current_file_parent_dir_name = file_path.parent.name
    is_in_swagger_client_root = (file_path.parent == swagger_client_root)
    is_in_api_subfolder = (current_file_parent_dir_name == "api" and file_path.parent.parent == swagger_client_root)

    if current_filename == "__init__.py" and is_in_swagger_client_root:
        # Target: from .api import DefaultApi
        # Original may be: from .default_api import DefaultApi (codegen typical)
        # or from swagger_client.default_api import DefaultApi
        content = re.sub(r"from\s+(?:swagger_client\.|\.)(?:api\.)?default_api\s+import\s+DefaultApi", "from .api import DefaultApi", content)
        
        # Ensure other direct imports are single-dot relative if from swagger_client
        content = re.sub(r'from swagger_client\.api_client', 'from .api_client', content)
        content = re.sub(r'from swagger_client\.configuration', 'from .configuration', content)
        content = re.sub(r'import swagger_client\.api_client', 'import .api_client', content)
        content = re.sub(r'import swagger_client\.configuration', 'import .configuration', content)
        content = re.sub(r'from swagger_client\.models', 'from .models', content)
        content = re.sub(r'import swagger_client\.models', 'import .models', content)

    elif current_filename == "__init__.py" and is_in_api_subfolder:
        # Target: from .default_api import DefaultApi
        # Original may be: from swagger_client.api.default_api import DefaultApi (codegen typical)
        content = re.sub(r"from\s+(?:swagger_client\.api\.|\.\.api\.|\.)default_api\s+import\s+DefaultApi", "from .default_api import DefaultApi", content)

    elif current_filename == "default_api.py" and is_in_api_subfolder:
        # Imports in api/default_api.py need to go up one level for models, api_client, configuration
        # from swagger_client.models.xyz import Xyz -> from ..models.xyz import Xyz
        # from swagger_client import ApiClient -> from .. import ApiClient (or from ..api_client import ApiClient)
        content = re.sub(r'from swagger_client\.models', 'from ..models', content)
        content = re.sub(r'import swagger_client\.models', 'import ..models', content)
        content = re.sub(r'from swagger_client\.api_client import ApiClient', 'from ..api_client import ApiClient', content) # More specific
        content = re.sub(r'from swagger_client import ApiClient', 'from ..api_client import ApiClient', content) # Broader
        content = re.sub(r'from swagger_client import Configuration', 'from ..configuration import Configuration', content)
        # Also handle 'import swagger_client' if it's used for ApiClient or Configuration implicitly
        # This is less common for direct usage but good to cover if 'swagger_client.ApiClient' syntax is used
        content = re.sub(r'import swagger_client', 'import ..', content) 

    elif current_filename == "api_client.py" and is_in_swagger_client_root:
        # Imports in api_client.py (at swagger_client root)
        # from swagger_client.models.xyz import Xyz -> from .models.xyz import Xyz
        # from swagger_client.configuration import Configuration -> from .configuration import Configuration
        content = re.sub(r'from swagger_client\.models', 'from .models', content)
        content = re.sub(r'import swagger_client\.models', 'import .models', content)
        content = re.sub(r'from swagger_client\.configuration', 'from .configuration', content)
        content = re.sub(r'import swagger_client\.configuration', 'import .configuration', content)

    elif current_filename == "configuration.py" and is_in_swagger_client_root:
        # Typically, configuration.py has no swagger_client imports, but check just in case
        pass # No common patterns to fix here, usually self-contained or stdlib imports

    # General rule for model files (and other files not specifically handled)
    # This assumes they are in swagger_client/models/ or other subdirs
    elif file_path.parent.name == "models" and file_path.parent.parent == swagger_client_root:
        # from swagger_client.models.other_model import OtherModel -> from .other_model import OtherModel
        # or if a model imports another model from a different package (less common)
        # from swagger_client.xyz import Xyz -> from ..xyz import Xyz (if models is one deep)
        content = re.sub(r'from swagger_client\.models', 'from .models', content) # for sibling models
        content = re.sub(r'import swagger_client\.models', 'import .models', content)
        # If models import from top-level (e.g. configuration - unlikely but possible)
        content = re.sub(r'from swagger_client\.configuration', 'from ..configuration', content)
    
    else: # Fallback for any other files not covered explicitly, using depth-based
        try:
            relative_dir_of_file = file_path.parent.relative_to(swagger_client_root)
        except ValueError:
            print(f"Error: File {file_path} does not seem to be under swagger_client_root {swagger_client_root}")
            return
        depth = len(relative_dir_of_file.parts)
        dot_prefix = "." + "." * depth

        content = re.sub(r'from swagger_client\.([\w.]+)', rf'from {dot_prefix}.\1', content)
        content = re.sub(r'import swagger_client\.([\w.]+)', rf'import {dot_prefix}.\1', content)


    if content != original_content:
        print(f"Updating imports in: {file_path.relative_to(project_root)}")
        print_debug_info(file_path, content, "After processing, changes made")
        try:
            file_path.write_text(content, encoding='utf-8')
        except Exception as e:
            print(f"Error writing file {file_path}: {e}")
    else:
        # print_debug_info(file_path, content, "After processing, no changes") # Can be noisy
        print(f"No import changes needed for: {file_path.relative_to(project_root)}")

def main():
    # Determine the project root (assuming script is in 'scripts/' subdirectory of project root)
    try:
        project_root = Path(__file__).resolve().parent.parent
    except NameError: # Fallback if __file__ is not defined (e.g. interactive)
        project_root = Path(".").resolve()

    print(f"Project root identified as: {project_root}")
    base_src_dir = project_root / 'src' / 'streetmanager'

    submodule_types = ["work", "geojson", "lookup"]

    for submodule_name in submodule_types:
        swagger_client_root = base_src_dir / submodule_name / "swagger_client"
        if swagger_client_root.is_dir():
            print(f"\nProcessing swagger client module: {swagger_client_root.relative_to(project_root)}")
            
            python_files = list(swagger_client_root.rglob('*.py'))
            if not python_files:
                print(f"No Python files found in {swagger_client_root.relative_to(project_root)}")
                continue
            
            python_files.sort()

            for file_path in python_files:
                convert_imports_in_file(file_path, swagger_client_root, project_root)
        else:
            print(f"Directory not found, skipping: {swagger_client_root.relative_to(project_root)}")

    print("\nImport fixing process completed.")

if __name__ == '__main__':
    main() 


# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FPNCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'fpn_evidence': 'bool',
        'file_ids': 'list[float]',
        'offence_date': 'datetime',
        'offence_code': 'OffenceCode',
        'offence_details': 'str',
        'authorised_officer': 'str',
        'officer_contact_details': 'str',
        'officer_address': 'str',
        'representations_contact': 'str',
        'representations_contact_address': 'str',
        'payment_methods': 'list[PaymentMethod]',
        'permit_reference_number': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'fpn_evidence': 'fpn_evidence',
        'file_ids': 'file_ids',
        'offence_date': 'offence_date',
        'offence_code': 'offence_code',
        'offence_details': 'offence_details',
        'authorised_officer': 'authorised_officer',
        'officer_contact_details': 'officer_contact_details',
        'officer_address': 'officer_address',
        'representations_contact': 'representations_contact',
        'representations_contact_address': 'representations_contact_address',
        'payment_methods': 'payment_methods',
        'permit_reference_number': 'permit_reference_number'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, fpn_evidence=None, file_ids=None, offence_date=None, offence_code=None, offence_details=None, authorised_officer=None, officer_contact_details=None, officer_address=None, representations_contact=None, representations_contact_address=None, payment_methods=None, permit_reference_number=None):  # noqa: E501
        """FPNCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._fpn_evidence = None
        self._file_ids = None
        self._offence_date = None
        self._offence_code = None
        self._offence_details = None
        self._authorised_officer = None
        self._officer_contact_details = None
        self._officer_address = None
        self._representations_contact = None
        self._representations_contact_address = None
        self._payment_methods = None
        self._permit_reference_number = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.fpn_evidence = fpn_evidence
        if file_ids is not None:
            self.file_ids = file_ids
        self.offence_date = offence_date
        self.offence_code = offence_code
        self.offence_details = offence_details
        self.authorised_officer = authorised_officer
        self.officer_contact_details = officer_contact_details
        self.officer_address = officer_address
        self.representations_contact = representations_contact
        self.representations_contact_address = representations_contact_address
        self.payment_methods = payment_methods
        if permit_reference_number is not None:
            self.permit_reference_number = permit_reference_number

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this FPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this FPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this FPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this FPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this FPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this FPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def fpn_evidence(self):
        """Gets the fpn_evidence of this FPNCreateRequest.  # noqa: E501

        Whether FPN evidence has been supplied  # noqa: E501

        :return: The fpn_evidence of this FPNCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._fpn_evidence

    @fpn_evidence.setter
    def fpn_evidence(self, fpn_evidence):
        """Sets the fpn_evidence of this FPNCreateRequest.

        Whether FPN evidence has been supplied  # noqa: E501

        :param fpn_evidence: The fpn_evidence of this FPNCreateRequest.  # noqa: E501
        :type: bool
        """
        if fpn_evidence is None:
            raise ValueError("Invalid value for `fpn_evidence`, must not be `None`")  # noqa: E501

        self._fpn_evidence = fpn_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this FPNCreateRequest.  # noqa: E501

        Required if fpn_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this FPNCreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this FPNCreateRequest.

        Required if fpn_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this FPNCreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    @property
    def offence_date(self):
        """Gets the offence_date of this FPNCreateRequest.  # noqa: E501

        offence_date must be in the past  # noqa: E501

        :return: The offence_date of this FPNCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._offence_date

    @offence_date.setter
    def offence_date(self, offence_date):
        """Sets the offence_date of this FPNCreateRequest.

        offence_date must be in the past  # noqa: E501

        :param offence_date: The offence_date of this FPNCreateRequest.  # noqa: E501
        :type: datetime
        """
        if offence_date is None:
            raise ValueError("Invalid value for `offence_date`, must not be `None`")  # noqa: E501

        self._offence_date = offence_date

    @property
    def offence_code(self):
        """Gets the offence_code of this FPNCreateRequest.  # noqa: E501


        :return: The offence_code of this FPNCreateRequest.  # noqa: E501
        :rtype: OffenceCode
        """
        return self._offence_code

    @offence_code.setter
    def offence_code(self, offence_code):
        """Sets the offence_code of this FPNCreateRequest.


        :param offence_code: The offence_code of this FPNCreateRequest.  # noqa: E501
        :type: OffenceCode
        """
        if offence_code is None:
            raise ValueError("Invalid value for `offence_code`, must not be `None`")  # noqa: E501

        self._offence_code = offence_code

    @property
    def offence_details(self):
        """Gets the offence_details of this FPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The offence_details of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._offence_details

    @offence_details.setter
    def offence_details(self, offence_details):
        """Sets the offence_details of this FPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param offence_details: The offence_details of this FPNCreateRequest.  # noqa: E501
        :type: str
        """
        if offence_details is None:
            raise ValueError("Invalid value for `offence_details`, must not be `None`")  # noqa: E501

        self._offence_details = offence_details

    @property
    def authorised_officer(self):
        """Gets the authorised_officer of this FPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The authorised_officer of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._authorised_officer

    @authorised_officer.setter
    def authorised_officer(self, authorised_officer):
        """Sets the authorised_officer of this FPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param authorised_officer: The authorised_officer of this FPNCreateRequest.  # noqa: E501
        :type: str
        """
        if authorised_officer is None:
            raise ValueError("Invalid value for `authorised_officer`, must not be `None`")  # noqa: E501

        self._authorised_officer = authorised_officer

    @property
    def officer_contact_details(self):
        """Gets the officer_contact_details of this FPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The officer_contact_details of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._officer_contact_details

    @officer_contact_details.setter
    def officer_contact_details(self, officer_contact_details):
        """Sets the officer_contact_details of this FPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param officer_contact_details: The officer_contact_details of this FPNCreateRequest.  # noqa: E501
        :type: str
        """
        if officer_contact_details is None:
            raise ValueError("Invalid value for `officer_contact_details`, must not be `None`")  # noqa: E501

        self._officer_contact_details = officer_contact_details

    @property
    def officer_address(self):
        """Gets the officer_address of this FPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The officer_address of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._officer_address

    @officer_address.setter
    def officer_address(self, officer_address):
        """Sets the officer_address of this FPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param officer_address: The officer_address of this FPNCreateRequest.  # noqa: E501
        :type: str
        """
        if officer_address is None:
            raise ValueError("Invalid value for `officer_address`, must not be `None`")  # noqa: E501

        self._officer_address = officer_address

    @property
    def representations_contact(self):
        """Gets the representations_contact of this FPNCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The representations_contact of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._representations_contact

    @representations_contact.setter
    def representations_contact(self, representations_contact):
        """Sets the representations_contact of this FPNCreateRequest.

        Max length 100 characters  # noqa: E501

        :param representations_contact: The representations_contact of this FPNCreateRequest.  # noqa: E501
        :type: str
        """
        if representations_contact is None:
            raise ValueError("Invalid value for `representations_contact`, must not be `None`")  # noqa: E501

        self._representations_contact = representations_contact

    @property
    def representations_contact_address(self):
        """Gets the representations_contact_address of this FPNCreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The representations_contact_address of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._representations_contact_address

    @representations_contact_address.setter
    def representations_contact_address(self, representations_contact_address):
        """Sets the representations_contact_address of this FPNCreateRequest.

        Max length 500 characters  # noqa: E501

        :param representations_contact_address: The representations_contact_address of this FPNCreateRequest.  # noqa: E501
        :type: str
        """
        if representations_contact_address is None:
            raise ValueError("Invalid value for `representations_contact_address`, must not be `None`")  # noqa: E501

        self._representations_contact_address = representations_contact_address

    @property
    def payment_methods(self):
        """Gets the payment_methods of this FPNCreateRequest.  # noqa: E501


        :return: The payment_methods of this FPNCreateRequest.  # noqa: E501
        :rtype: list[PaymentMethod]
        """
        return self._payment_methods

    @payment_methods.setter
    def payment_methods(self, payment_methods):
        """Sets the payment_methods of this FPNCreateRequest.


        :param payment_methods: The payment_methods of this FPNCreateRequest.  # noqa: E501
        :type: list[PaymentMethod]
        """
        if payment_methods is None:
            raise ValueError("Invalid value for `payment_methods`, must not be `None`")  # noqa: E501

        self._payment_methods = payment_methods

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this FPNCreateRequest.  # noqa: E501

        The permit_reference_number of the associated permit  # noqa: E501

        :return: The permit_reference_number of this FPNCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this FPNCreateRequest.

        The permit_reference_number of the associated permit  # noqa: E501

        :param permit_reference_number: The permit_reference_number of this FPNCreateRequest.  # noqa: E501
        :type: str
        """

        self._permit_reference_number = permit_reference_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FPNCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FPNCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitDurationChallengeNonAcceptanceResponseRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'non_acceptance_response_status': 'DurationChallengeNonAcceptanceResponseStatus',
        'new_reasonable_period_end_date': 'datetime',
        'non_acceptance_response_details': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'non_acceptance_response_status': 'non_acceptance_response_status',
        'new_reasonable_period_end_date': 'new_reasonable_period_end_date',
        'non_acceptance_response_details': 'non_acceptance_response_details'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, non_acceptance_response_status=None, new_reasonable_period_end_date=None, non_acceptance_response_details=None):  # noqa: E501
        """PermitDurationChallengeNonAcceptanceResponseRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._non_acceptance_response_status = None
        self._new_reasonable_period_end_date = None
        self._non_acceptance_response_details = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.non_acceptance_response_status = non_acceptance_response_status
        if new_reasonable_period_end_date is not None:
            self.new_reasonable_period_end_date = new_reasonable_period_end_date
        self.non_acceptance_response_details = non_acceptance_response_details

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def non_acceptance_response_status(self):
        """Gets the non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501


        :return: The non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: DurationChallengeNonAcceptanceResponseStatus
        """
        return self._non_acceptance_response_status

    @non_acceptance_response_status.setter
    def non_acceptance_response_status(self, non_acceptance_response_status):
        """Sets the non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.


        :param non_acceptance_response_status: The non_acceptance_response_status of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: DurationChallengeNonAcceptanceResponseStatus
        """
        if non_acceptance_response_status is None:
            raise ValueError("Invalid value for `non_acceptance_response_status`, must not be `None`")  # noqa: E501

        self._non_acceptance_response_status = non_acceptance_response_status

    @property
    def new_reasonable_period_end_date(self):
        """Gets the new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Required if non_acceptance_response_status = reasonable_period_end_date_changed  # noqa: E501

        :return: The new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._new_reasonable_period_end_date

    @new_reasonable_period_end_date.setter
    def new_reasonable_period_end_date(self, new_reasonable_period_end_date):
        """Sets the new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Required if non_acceptance_response_status = reasonable_period_end_date_changed  # noqa: E501

        :param new_reasonable_period_end_date: The new_reasonable_period_end_date of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: datetime
        """

        self._new_reasonable_period_end_date = new_reasonable_period_end_date

    @property
    def non_acceptance_response_details(self):
        """Gets the non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :rtype: str
        """
        return self._non_acceptance_response_details

    @non_acceptance_response_details.setter
    def non_acceptance_response_details(self, non_acceptance_response_details):
        """Sets the non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.

        Max length 500 characters  # noqa: E501

        :param non_acceptance_response_details: The non_acceptance_response_details of this PermitDurationChallengeNonAcceptanceResponseRequest.  # noqa: E501
        :type: str
        """
        if non_acceptance_response_details is None:
            raise ValueError("Invalid value for `non_acceptance_response_details`, must not be `None`")  # noqa: E501

        self._non_acceptance_response_details = non_acceptance_response_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitDurationChallengeNonAcceptanceResponseRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitDurationChallengeNonAcceptanceResponseRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3

import os
import re

def fix_imports_in_file(file_path):
    """Fix imports in a single file by replacing absolute imports with relative ones."""
    with open(file_path, 'r') as f:
        content = f.read()
    
    # Replace absolute imports with relative imports
    modified_content = re.sub(
        r'from swagger_client\.models\.(\w+) import',
        r'from .\1 import',
        content
    )
    
    if content != modified_content:
        with open(file_path, 'w') as f:
            f.write(modified_content)
        print(f"Fixed imports in {file_path}")
    else:
        print(f"No changes needed in {file_path}")

def main():
    """Main function to fix imports in all model files."""
    # Get the directory of this script
    script_dir = os.path.dirname(os.path.abspath(__file__))
    
    # Path to the models directory
    models_dir = os.path.join(script_dir, 'swagger_client', 'models')
    
    # Walk through all Python files in the models directory
    for root, _, files in os.walk(models_dir):
        for file in files:
            if file.endswith('.py'):
                file_path = os.path.join(root, file)
                fix_imports_in_file(file_path)

if __name__ == '__main__':
    main() 


#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script will:
1. Find all Python files in the swagger_client directory
2. Convert all 'from swagger_client.' imports to 'from .'
3. Collapse any double occurrences of '.api.api.' to '.api.' and '.models.models.' to '.models.'
4. Preserve the rest of the file content
"""

import re
from pathlib import Path

def convert_imports(file_path):
    """Convert absolute imports to relative imports in a file."""
    with open(file_path, 'r', encoding='utf-8') as f:
        content = f.read()

    # Replace all 'from swagger_client.' with 'from .'
    content = re.sub(r'from swagger_client\.', 'from .', content)

    # Collapse any double occurrences of '.api.api.' to '.api.' and '.models.models.' to '.models.'
    content = re.sub(r'\.api\.api\.', '.api.', content)
    content = re.sub(r'\.models\.models\.', '.models.', content)

    with open(file_path, 'w', encoding='utf-8') as f:
        f.write(content)

def main():
    base_dir = Path('src/streetmanager/*/swagger_client')
    python_files = list(base_dir.rglob('*.py'))
    for file_path in python_files:
        print(f"Processing {file_path}")
        convert_imports(file_path)
        print(f"Completed {file_path}")

if __name__ == '__main__':
    main() 